@@ -18,9 +18,10 @@ __author__ = "Simon Matthews and Kevin Wong"
 __all__ = ['Mantle', 'hydrous_lithology']
 
 import pyMelt.lithologies
-import pyMelt.geosettings
 # import pyMelt.meltingcolumn_classes
-from pyMelt.mantle_class import mantle
-from pyMelt.lithology_classes import hydrousLithology
+import pyMelt.mantle_class
+from pyMelt.lithology_classes import hydrous_lithology
 
-__all__ = ['hydrousLithology', 'mantle']
+
+class Mantle(pyMelt.mantle_class.mantle):
+    __doc__ = pyMelt.mantle_class.mantle.__doc__
