@@ -3,7 +3,7 @@ from warnings import warn
 import pandas as pd
 from scipy.optimize import fsolve
 
-from pyMelt.meltingcolumn_classes import meltingColumn
+from pyMelt.meltingcolumn_classes import MeltingColumn_1D
 
 
 class mantle:
@@ -39,17 +39,16 @@ class mantle:
         the entropy change on melting of each lithology.
 
     """
-
     def __init__(self, lithologies, proportions, names=None):
         self.lithologies = lithologies
         if isinstance(proportions, list):
             proportions = np.array(proportions)
-        self.proportions = proportions / sum(proportions)
+        self.proportions = proportions/sum(proportions)
         self.number_lithologies = np.shape(self.lithologies)[0]
         if names is None:
             names = list()
             for i in range(self.number_lithologies):
-                names.append('default ' + str(i))
+                names.append('default '+str(i))
         self.names = names
 
         self.CP = np.zeros(self.number_lithologies)
@@ -66,7 +65,7 @@ class mantle:
             self.rhos[i] = self.lithologies[i].rhos
             self.DeltaS[i] = self.lithologies[i].DeltaS
 
-    def bulkProperties(self, P=None, T=None):
+    def bulk_properties(self, P=None, T=None):
         """
             Calculates the bulk thermodynamic properties of the solid or partially
             molten mantle.
@@ -90,13 +89,13 @@ class mantle:
         if T is not None:
             for i in range(self.number_lithologies):
                 F[i] = self.lithologies[i].F(P, T)
-        alpha = sum(self.proportions * self.alphaf * F + self.proportions * self.alphas * (1 - F))
-        CP = sum(self.proportions * self.CP)
-        rho = sum(self.proportions * self.rhof * F + self.proportions * self.rhos * (1 - F))
+        alpha = sum(self.proportions*self.alphaf*F + self.proportions*self.alphas*(1-F))
+        CP = sum(self.proportions*self.CP)
+        rho = sum(self.proportions*self.rhof*F + self.proportions*self.rhos*(1-F))
 
         return {'alpha': alpha, 'CP': CP, 'rho': rho}
 
-    def solidusIntersection(self, Tp):
+    def solidus_intersection(self, Tp):
         """
         Finds the pressure at which each lithology's solidus will be intersected,
         assuming the mantle follows the solid adiabat up until that point.
@@ -118,17 +117,14 @@ class mantle:
             # Check that the lithology actually melts:
             if self.lithologies[i].TSolidus(3.0) is np.inf:
                 intersect[i] = np.nan
-            # Check there is actually some of the lithology:
-            elif self.proportions[i] > 0:
+            else:
                 try:
                     intersect[i] = fsolve(f_solve, 3.0)[0]
                 except Exception:
                     intersect[i] = np.nan
-            else:
-                intersect[i] = np.nan
         return intersect
 
-    def solidusIntersectionIsobaric(self, P):
+    def solidus_intersection_isobaric(self, P):
         """
         Finds the pressure at which each lithology's solidus will be intersected,
         assuming the mantle is heated isobarically.
@@ -165,9 +161,9 @@ class mantle:
         float or numpy.array
             Temperature of the mantle at the given pressure and Tp.
         """
-        bulk_props = self.bulkProperties(P)
-        T = ((Tp + 273.15) * np.exp(bulk_props['alpha']
-             / (bulk_props['rho'] * bulk_props['CP']) * P) - 273.15)
+        bulk_props = self.bulk_properties(P)
+        T = ((Tp + 273.15) * np.exp(bulk_props['alpha'] /
+             (bulk_props['rho'] * bulk_props['CP']) * P) - 273.15)
         return T
 
     def F(self, P, T):
@@ -192,7 +188,7 @@ class mantle:
             F[i] = self.lithologies[i].F(P, T)
         return F
 
-    def dFdP(self, P, T, prevent_freezing=False):
+    def dFdP(self, P, T):
         """
         Calculates the value of dFdP for each lithology at the given pressure
         and temperature, using Eq(26) of Phipps Morgan (2001).
@@ -203,8 +199,6 @@ class mantle:
             Pressure in GPa.
         T : float
             Temperature in degC.
-        prevent_freezing : bool, default: False
-            If set to True, any dFdP values > 0 will be set to 0.
 
         Returns
         -------
@@ -222,35 +216,32 @@ class mantle:
             dTdF[i] = self.lithologies[i].dTdF(P, T)
             F[i] = self.lithologies[i].F(P, T)
 
-        lithologies_melting = np.where((F * self.proportions > 0) & (F * self.proportions < 1))[0]
+        lithologies_melting = np.where((F > 0) & (F < 1))[0]
 
         if np.shape(lithologies_melting)[0] > 0:
             for i in range(np.shape(lithologies_melting)[0]):
-                not_key = [True] * self.number_lithologies
+                not_key = [True]*self.number_lithologies
                 key = lithologies_melting[i]
                 not_key[key] = False
 
-                bulk_props = self.bulkProperties(P, T)
+                bulk_props = self.bulk_properties(P, T)
 
                 # Equation (26) from PM2001 to find dFdP of first lithology
-                top = (bulk_props['CP'] / (T + 273.15) * dTdP[key]
-                       - bulk_props['alpha'] / bulk_props['rho']
-                       + sum(self.proportions[not_key] * self.DeltaS[not_key]
-                             * (dTdP[key] - dTdP[not_key]) / dTdF[not_key]))
+                top = (bulk_props['CP'] / (T+273.15) * dTdP[key] -
+                       bulk_props['alpha']/bulk_props['rho'] +
+                       sum(self.proportions[not_key] * self.DeltaS[not_key] *
+                           (dTdP[key] - dTdP[not_key]) / dTdF[not_key]))
 
-                bottom = (self.proportions[key] * self.DeltaS[key]
-                          + sum(self.proportions[not_key] * self.DeltaS[not_key]
-                          * dTdF[key] / dTdF[not_key])
-                          + bulk_props['CP'] / (T + 273.15) * dTdF[key])
+                bottom = (self.proportions[key] * self.DeltaS[key] +
+                          sum(self.proportions[not_key] * self.DeltaS[not_key] *
+                              dTdF[key] / dTdF[not_key]) +
+                          bulk_props['CP'] / (T+273.15) * dTdF[key])
 
-                dFdP[key] = - top / bottom
-
-                if prevent_freezing is True and dFdP[key] > 0:
-                    dFdP[key] = 0.0
+                dFdP[key] = - top/bottom
 
         return dFdP
 
-    def adiabaticGradient(self, P, T):
+    def adiabatic_gradient(self, P, T):
         """
         Calculates dTdP if melting has gone to completion (or hasn't started) for the bulk mantle.
 
@@ -267,9 +258,9 @@ class mantle:
             The adiabatic gradient in C/GPa
         """
 
-        bulk_props = self.bulkProperties(P, T)
+        bulk_props = self.bulk_properties(P, T)
 
-        dTdP = bulk_props['alpha'] * (T + 273.15) / bulk_props['rho'] / bulk_props['CP']
+        dTdP = bulk_props['alpha'] * (T+273.15) / bulk_props['rho'] / bulk_props['CP']
 
         return dTdP
 
@@ -305,11 +296,11 @@ class mantle:
             key = melting_lithologies[key]
             dTdP = self.lithologies[key].dTdP(P, T) + self.lithologies[key].dTdF(P, T) * dFdP[key]
         else:
-            dTdP = self.adiabaticGradient(P, T)
+            dTdP = self.adiabatic_gradient(P, T)
 
         return dTdP
 
-    def isobaricMelt(self, Tstart, P, dT=0.1):
+    def IsobaricMelt_1D(self, Tstart, P, dT=0.1):
         """
         Calculates the amount of melt generated, and the mantle's temperature, after
         an interval of melting occuring due to mantle being instantaneously placed
@@ -334,26 +325,25 @@ class mantle:
             Temperature of mantle following the melting step.
         """
 
-        solidus_intersection = self.solidusIntersectionIsobaric(P)
+        solidus_intersection = self.solidus_intersection_isobaric(P)
 
         # Calculate the entropy lost associated with cooling solid material to the
         # solidus temperature
         solT = np.nanmin(solidus_intersection)
-        bulk_props = self.bulkProperties(P, solT)
+        bulk_props = self.bulk_properties(P, solT)
         DeltaS_cool = - bulk_props['CP'] * np.log((solT + 273.15) / (Tstart + 273.15))
 
         DeltaS_melt = 0
         T = solT + dT
         while DeltaS_melt < DeltaS_cool and T < Tstart:
-            bulk_props = self.bulkProperties(P, T)
+            bulk_props = self.bulk_properties(P, T)
             DeltaS_melt = (np.sum(self.F(P, T) * self.proportions * self.DeltaS) +
                            - bulk_props['CP'] * np.log((solT + 273.15) / (T + 273.15)))
             T = T + dT
 
         return T
 
-    def adiabaticMelt(self, Tp, Pstart=None, Pend=0.01, dP=-0.004, steps=None, ReportSSS=True,
-                      adjust_pressure=True, prevent_freezing=True, warn_prevent_freezing=True):
+    def AdiabaticMelt_1D(self, Tp, Pstart=8.0, Pend=0.01, steps=101, ReportSSS=True):
         """
         Performs simultaneous integration of dFdP and dTdP to obtain the thermal gradient
         through the melting region. F of each lithology is then calculated using the P,T path.
@@ -363,114 +353,72 @@ class mantle:
 
         Parameters
         ----------
-        Tp : float
+        Tp :        float
             The potential temperature (degC) at which to perform the calculation.
-        Pstart : float or None, default: None
-            The pressure (in GPa) at which to begin upwelling. If None, the calculation will start
-            at the solidus.
-        Pend : float, default: 0.0
+        Pstart :    float, default: 8.0
+            The pressure (in GPa) at which to begin upwelling.
+        Pend :      float, default: 0.0
             The pressure (in GPa) at which to stop upwelling.
-        dP : float, default: -0.004
-            The step size in pressure (GPa) to use in the calculation. If the argument steps is
-            set, dP will be ignored.
-        steps : None or int, default: None
-            The number of dP increments to split the melting region into. If set to None, the
-            number of steps is determined by dP.
+        steps :     int, default: 101
+            The number of dP increments to split the melting region into.
         ReportSSS : bool, default: True
             Print to the console if the start is above the solidus of one of the lithologies.
             Either way the code will calculate the melt fraction at this point by conserving
             entropy. Set to False if you don't want to be warned.
-        adjust_pressure : bool, default: True
-            If True, the pressure range will be adjusted slightly so that one point coincides with
-            the solidus. This should avoid issues with discretisation.
-        prevent_freezing : bool, default: True
-            In some melting regions heat extraction by one lithology can cause another's melts to
-            partially freeze (releasing some heat). If set to True this is prevented from
-            happening. This is most useful when modelling fractional melt extraction.
-        warn_prevent_freezing : bool, default: True
-            If set to True, when a melt is prevented from freezing, a warning will be raised.
 
         Returns
         -------
-        pyMelt.meltingColumn
+        pyMelt.MeltingColumn_1D
             The results are returned in a 1D Melting Column instance, further calculations, e.g.
             crustal thickness may then be performed on this instance, if desired.
         """
 
-        if Pstart is None:
-            solidus_intersect = self.solidusIntersection(Tp)
-            Pstart = np.nanmax(solidus_intersect) + 1e-5
-            adjust_pressure = False
-
-        if steps is None:
-            P = np.arange(Pstart, Pend, dP)
-            steps = len(P)
-        else:
-            P = np.linspace(Pstart, Pend, steps)
-            dP = (Pend - Pstart) / (steps - 1)
-
         T = np.zeros(steps)
         T[0] = self.adiabat(Pstart, Tp)
-
-        if (adjust_pressure is True
-                and T[0] < np.nanmin(self.solidusIntersectionIsobaric(Pstart))):
-            p_intersect = np.nanmax(self.solidusIntersection(Tp))
-            diff = np.abs(P - p_intersect)
-            adjustment = P[np.argmin(diff)] - p_intersect
-            if adjustment < 0:
-                adjustment += dP
-            P -= adjustment
-
+        P = np.linspace(Pstart, Pend, steps)
+        dP = (Pend - Pstart) / (steps - 1)
         F = np.zeros([steps, self.number_lithologies])
 
-        if T[0] > np.nanmin(self.solidusIntersectionIsobaric(Pstart)):
+        if T[0] > np.nanmin(self.solidus_intersection_isobaric(Pstart)):
             if ReportSSS is True:
                 warn("Super solidus start")
-            T[0] = self.isobaricMelt(T[0], Pstart)
+            T[0] = self.IsobaricMelt_1D(T[0], Pstart)
 
         for i in range(steps):
             if i == 0:
                 F[i] = self.F(P[0], T[0])
             else:
                 # If melting has not started
-                if np.shape(np.where((F[i - 1] * self.proportions > 0))[0])[0] == 0:
+                if np.shape(np.where((F[i-1] > 0))[0])[0] == 0:
                     T[i] = self.adiabat(P[i], Tp)
                     F[i] = self.F(P[i], T[i])
 
                 # If melting has gone to completion
-                elif (np.shape(np.where((F[i - 1] * self.proportions > 0)
-                                        & (F[i - 1] * self.proportions < 1))[0])[0] == 0):
-                    j1 = self.adiabaticGradient(P[i - 1], T[i - 1])
-                    j2 = self.adiabaticGradient(P[i - 1] + dP / 2, T[i - 1] + dP / 2 * j1)
-                    j3 = self.adiabaticGradient(P[i - 1] + dP / 2, T[i - 1] + dP / 2 * j2)
-                    j4 = self.adiabaticGradient(P[i], T[i - 1] + dP * j3)
+                elif np.shape(np.where((F[i-1] > 0) & (F[i-1] < 1))[0])[0] == 0:
+                    j1 = self.adiabatic_gradient(P[i-1], T[i-1])
+                    j2 = self.adiabatic_gradient(P[i-1] + dP/2, T[i-1] + dP/2*j1)
+                    j3 = self.adiabatic_gradient(P[i-1] + dP/2, T[i-1] + dP/2*j2)
+                    j4 = self.adiabatic_gradient(P[i], T[i-1] + dP*j3)
 
-                    T[i] = T[i - 1] + dP / 6 * (j1 + 2 * j2 + 2 * j3 + j4)
+                    T[i] = T[i-1] + dP/6*(j1 + 2*j2 + 2*j3 + j4)
                     F[i] = self.F(P[i], T[i])
 
                 # If melting is ongoing
                 else:
-                    k1 = self.dFdP(P[i - 1], T[i - 1], prevent_freezing)
-                    j1 = self.dTdP(P[i - 1], T[i - 1], k1)
-                    k2 = self.dFdP(P[i - 1] + dP / 2, T[i - 1] + dP / 2 * j1, prevent_freezing)
-                    j2 = self.dTdP(P[i - 1] + dP / 2, T[i - 1] + dP / 2 * j1, k2)
-                    k3 = self.dFdP(P[i - 1] + dP / 2, T[i - 1] + dP / 2 * j2, prevent_freezing)
-                    j3 = self.dTdP(P[i - 1] + dP / 2, T[i - 1] + dP / 2 * j2, k3)
-                    k4 = self.dFdP(P[i], T[i - 1] + dP * j3, prevent_freezing)
-                    j4 = self.dTdP(P[i], T[i - 1] + dP * j3, k4)
+                    k1 = self.dFdP(P[i-1], T[i-1])
+                    j1 = self.dTdP(P[i-1], T[i-1], k1)
+                    k2 = self.dFdP(P[i-1] + dP/2, T[i-1] + dP/2*j1)
+                    j2 = self.dTdP(P[i-1] + dP/2, T[i-1] + dP/2*j1, k2)
+                    k3 = self.dFdP(P[i-1] + dP/2, T[i-1] + dP/2*j2)
+                    j3 = self.dTdP(P[i-1] + dP/2, T[i-1] + dP/2*j2, k3)
+                    k4 = self.dFdP(P[i], T[i-1] + dP*j3)
+                    j4 = self.dTdP(P[i], T[i-1] + dP*j3, k4)
 
-                    T[i] = T[i - 1] + dP / 6 * (j1 + 2 * j2 + 2 * j3 + j4)
+                    T[i] = T[i-1] + dP/6 * (j1 + 2*j2 + 2*j3 + j4)
                     F[i] = self.F(P[i], T[i])
 
-                    if prevent_freezing is True:
-                        for j in range(self.number_lithologies):
-                            if F[i, j] < F[i - 1, j]:
-                                F[i, j] = F[i - 1, j]
-                                if warn_prevent_freezing is True:
-                                    warn("Freezing prevented.")
-
         results = pd.DataFrame(F, columns=self.names)
         results['P'] = P
         results['T'] = T
 
-        return meltingColumn(results, self, Tp)
+        return MeltingColumn_1D(results, self, Tp)
